@@ -5,10 +5,10 @@ use warnings;
 # $Id: CheckMacros.pm.in 18477 2011-11-09 12:46:54Z squinney@INF.ED.AC.UK $
 # $Source: /var/cvs/dice/LCFG-Build-Tools/lib/LCFG/Build/Tool/CheckMacros.pm.in,v $
 # $Revision: 18477 $
-# $HeadURL: https://svn.lcfg.org/svn/source/tags/LCFG-Build-Tools/LCFG_Build_Tools_0_2_2/lib/LCFG/Build/Tool/CheckMacros.pm.in $
+# $HeadURL: https://svn.lcfg.org/svn/source/tags/LCFG-Build-Tools/LCFG_Build_Tools_0_3_1/lib/LCFG/Build/Tool/CheckMacros.pm.in $
 # $Date: 2011-11-09 12:46:54 +0000 (Wed, 09 Nov 2011) $
 
-our $VERSION = '0.2.2';
+our $VERSION = '0.3.1';
 
 use File::Spec ();
 use File::Temp ();
@@ -301,7 +301,7 @@ __END__
 
 =head1 VERSION
 
-    This documentation refers to LCFG::Build::Tool::CheckMacros version 0.2.2
+    This documentation refers to LCFG::Build::Tool::CheckMacros version 0.3.1
 
 =head1 SYNOPSIS
 
@@ -462,7 +462,7 @@ This is the list of platforms on which we have tested this
 software. We expect this software to work on any Unix-like platform
 which is supported by Perl.
 
-Fedora12, Fedora13, ScientificLinux5
+Fedora12, Fedora13, ScientificLinux5, ScientificLinux6, MacOSX7
 
 =head1 BUGS AND LIMITATIONS
 
