@@ -5,10 +5,10 @@ use warnings;
 # $Id: Tools.pm.in 12894 2010-07-12 15:44:11Z squinney@INF.ED.AC.UK $
 # $Source: /var/cvs/dice/LCFG-Build-Tools/lib/LCFG/Build/Tools.pm.in,v $
 # $Revision: 12894 $
-# $HeadURL: https://svn.lcfg.org/svn/source/tags/LCFG-Build-Tools/LCFG_Build_Tools_0_2_2/lib/LCFG/Build/Tools.pm.in $
+# $HeadURL: https://svn.lcfg.org/svn/source/tags/LCFG-Build-Tools/LCFG_Build_Tools_0_3_1/lib/LCFG/Build/Tools.pm.in $
 # $Date: 2010-07-12 16:44:11 +0100 (Mon, 12 Jul 2010) $
 
-our $VERSION = '0.2.2';
+our $VERSION = '0.3.1';
 
 use Moose;
 
@@ -29,7 +29,7 @@ __END__
 
 =head1 VERSION
 
-This documentation refers to LCFG::Build::Tools version 0.2.2
+This documentation refers to LCFG::Build::Tools version 0.3.1
 
 =head1 DESCRIPTION
 
@@ -161,7 +161,7 @@ This is the list of platforms on which we have tested this
 software. We expect this software to work on any Unix-like platform
 which is supported by Perl.
 
-Fedora12, Fedora13, ScientificLinux5
+Fedora12, Fedora13, ScientificLinux5, ScientificLinux6, MacOSX7
 
 =head1 BUGS AND LIMITATIONS
 
