@@ -5,10 +5,10 @@ use warnings;
 # $Id: RPM.pm.in 16250 2011-03-03 20:30:10Z squinney@INF.ED.AC.UK $
 # $Source: /var/cvs/dice/LCFG-Build-Tools/lib/LCFG/Build/Utils/RPM.pm.in,v $
 # $Revision: 16250 $
-# $HeadURL: https://svn.lcfg.org/svn/source/tags/LCFG-Build-Tools/LCFG_Build_Tools_0_2_2/lib/LCFG/Build/Utils/RPM.pm.in $
+# $HeadURL: https://svn.lcfg.org/svn/source/tags/LCFG-Build-Tools/LCFG_Build_Tools_0_3_1/lib/LCFG/Build/Utils/RPM.pm.in $
 # $Date: 2011-03-03 20:30:10 +0000 (Thu, 03 Mar 2011) $
 
-our $VERSION = '0.2.2';
+our $VERSION = '0.3.1';
 
 use DateTime   ();
 use English qw(-no_match_vars);
@@ -275,7 +275,7 @@ __END__
 
 =head1 VERSION
 
-    This documentation refers to LCFG::Build::Utils::RPM version 0.2.2
+    This documentation refers to LCFG::Build::Utils::RPM version 0.3.1
 
 =head1 SYNOPSIS
 
@@ -329,7 +329,7 @@ This is the list of platforms on which we have tested this
 software. We expect this software to work on any Unix-like platform
 which is supported by Perl.
 
-Fedora12, Fedora13, ScientificLinux5
+Fedora12, Fedora13, ScientificLinux5, ScientificLinux6, MacOSX7
 
 =head1 BUGS AND LIMITATIONS
 
